import React from "react";
import { Sidebar } from "./sidebar.styles";
import { Avatar, Tooltip } from "@nextui-org/react";
import { CompaniesDropdown } from "./companies-dropdown";
import { HomeIcon } from "../icons/sidebar/home-icon";
import { PaymentsIcon } from "../icons/sidebar/payments-icon";
import { BalanceIcon } from "../icons/sidebar/balance-icon";
import { AccountsIcon } from "../icons/sidebar/accounts-icon";
import { CustomersIcon } from "../icons/sidebar/customers-icon";
import { ProductsIcon } from "../icons/sidebar/products-icon";
import { ReportsIcon } from "../icons/sidebar/reports-icon";
import { DevIcon } from "../icons/sidebar/dev-icon";
import { ViewIcon } from "../icons/sidebar/view-icon";
import { SettingsIcon } from "../icons/sidebar/settings-icon";
import { CollapseItems } from "./collapse-items";
import { SidebarItem } from "./sidebar-item";
import { SidebarMenu } from "./sidebar-menu";
import { FilterIcon } from "../icons/sidebar/filter-icon";
import { useSidebarContext } from "../layout/layout-context";
import { ChangeLogIcon } from "../icons/sidebar/changelog-icon";
import { useLocation, BrowserRouter } from "react-router-dom";
import { useEffect } from "react";
import { ChatBubble } from "@mui/icons-material";
import Icon from "@mdi/react";
import { mdiCarOutline, mdiChat, mdiChatOutline } from "@mdi/js";
import { CarOutline } from "mdi-material-ui";
import { usePage, router } from "@inertiajs/react";

export const SidebarWrapper = () => {
    const { auth } = usePage().props;

    let user = auth.user;

    // const pathname = "pathename";
    const pathname = location.pathname;
    // useEffect(() => {
    //     console.log("PATHNAME_____", pathname);
    // }, []);

    const { collapsed, setCollapsed } = useSidebarContext();

    return (
        <BrowserRouter>
            <aside className="h-screen z-[202] sticky top-0">
                {collapsed ? (
                    <div className={Sidebar.Overlay()} onClick={setCollapsed} />
                ) : null}
                <div
                    className={Sidebar({
                        collapsed: collapsed,
                    })}
                >
                    <div className={Sidebar.Header()}>
                        {/* <CompaniesDropdown /> */}
                    </div>
                    <div className="flex flex-col justify-between h-full">
                        <div className={Sidebar.Body()}>
                            <SidebarItem
                                title="Dashboard"
                                icon={<HomeIcon />}
                                isActive={pathname === "/dashboard"}
                                href="/dashboard"
                            />
                            <SidebarMenu title="Main Menu">
                                {user.role == 10 && (
                                    <>
                                        <SidebarItem
                                            isActive={
                                                pathname ===
                                                "/dashboard/packages"
                                            }
                                            title="Add Packages"
                                            href="/dashboard/packages"
                                            icon={
                                                <Icon
                                                    path={mdiChatOutline}
                                                    size={1}
                                                />
                                            }
                                        />
                                        <SidebarItem
                                            isActive={
                                                pathname ===
                                                "/dashboard/blog-post"
                                            }
                                            title="Blog Posts"
                                            href="/dashboard/blog-post"
                                            icon={
                                                <Icon
                                                    path={mdiChatOutline}
                                                    size={1}
                                                />
                                            }
                                        />
                                        <SidebarItem
                                            isActive={
                                                pathname ===
                                                "/dashboard/destinations"
                                            }
                                            title="Destinations"
                                            href="/dashboard/destinations"
                                            icon={
                                                <Icon
                                                    path={mdiChatOutline}
                                                    size={1}
                                                />
                                            }
                                        />
                                    </>
                                )}
                                <SidebarItem
                                    isActive={
                                        pathname === "/dashboard/bookings"
                                    }
                                    title="My Bookings"
                                    icon={<ProductsIcon />}
                                    href="/dashboard"
                                    // href="/dashboard/bookings"
                                />
                                <SidebarItem
                                    isActive={pathname === "/profile"}
                                    title="Profile"
                                    icon={<AccountsIcon />}
                                    href="/profile"
                                />
                            </SidebarMenu>
                        </div>
                        <div className={Sidebar.Footer()}>
                            {/* <Tooltip content={"Settings"} color="primary">
                                <div className="max-w-fit">
                                    <SettingsIcon />
                                </div>
                            </Tooltip>
                            <Tooltip content={"Adjustments"} color="primary">
                                <div className="max-w-fit">
                                    <FilterIcon />
                                </div>
                            </Tooltip>
                            <Tooltip content={"Profile"} color="primary">
                                <Avatar
                                    src="https://i.pravatar.cc/150?u=a042581f4e29026704d"
                                    size="sm"
                                />
                            </Tooltip> */}
                        </div>
                    </div>
                </div>
            </aside>
        </BrowserRouter>
    );
};
